pub struct SidecarConfig {
pub enabled: bool,
pub min_confidence: f32,
pub min_score: f32,
pub timeout_ms: u64,
pub reinforce_on_check: bool,
pub reinforce_pass_score: f32,
pub reinforce_fail_score: f32,
}Expand description
Configuration for the memory sidecar relevance check.
Fields
enabled: boolmin_confidence: f32Minimum confidence to pass the entry through to the LLM for relevance check. Entries below this are pre-filtered.
min_score: f32Minimum relevance score from the LLM to keep a memory entry.
timeout_ms: u64Timeout for the LLM relevance check.
reinforce_on_check: boolIf true, reinforce entries that pass relevance check (positive) and decay entries that fail (negative).
reinforce_pass_score: f32Reinforcement score for passing entries.
reinforce_fail_score: f32Reinforcement score for failing entries.